@@ -1,6 +1,5 @@
-from __future__ import absolute_import
-
 from functools import partial
+import pickle
 
 import numpy as np
 import pandas as pd
@@ -8,10 +7,28 @@ from pandas.core.internals import create_block_manager_from_blocks, make_block
 
 from . import numpy as pnp
 from .core import Interface
-from .compatibility import pickle
 from .encode import Encode
 from .utils import extend, framesplit, frame
 
+try:
+    # pandas >= 0.24.0
+    from pandas.api.types import is_extension_array_dtype
+except ImportError:
+    def is_extension_array_dtype(dtype):
+        return False
+
+try:
+    # Some `ExtensionArray`s can have a `.dtype` which is not a `ExtensionDtype`
+    # (e.g. they can be backed by a NumPy dtype). For these cases we check
+    # whether the instance is a `ExtensionArray`.
+    # https://github.com/dask/partd/issues/48
+    from pandas.api.extensions import ExtensionArray
+    def is_extension_array(x):
+        return isinstance(x, ExtensionArray)
+except ImportError:
+    def is_extension_array(x):
+        return False
+
 
 dumps = partial(pickle.dumps, protocol=pickle.HIGHEST_PROTOCOL)
 
@@ -28,11 +45,11 @@ class PandasColumns(Interface):
 
         # TODO: don't use values, it does some work.  Look at _blocks instead
         #       pframe/cframe do this well
-        arrays = dict((extend(k, col), df[col].values)
+        arrays = {extend(k, col): df[col].values
                        for k, df in data.items()
-                       for col in df.columns)
-        arrays.update(dict((extend(k, '.index'), df.index.values)
-                            for k, df in data.items()))
+                       for col in df.columns}
+        arrays.update({extend(k, '.index'): df.index.values
+                            for k, df in data.items()})
         # TODO: handle categoricals
         self.partd.append(arrays, **kwargs)
 
@@ -91,7 +108,7 @@ def index_to_header_bytes(ind):
         cat = None
         values = ind.values
 
-    header = (type(ind), ind._get_attributes_dict(), values.dtype, cat)
+    header = (type(ind), {k: getattr(ind, k, None) for k in ind._attributes}, values.dtype, cat)
     bytes = pnp.compress(pnp.serialize(values), values.dtype)
     return header, bytes
 
@@ -121,18 +138,27 @@ def block_to_header_bytes(block):
     elif is_datetime64tz_dtype(block):
         extension = ('datetime64_tz_type', (block.values.tzinfo,))
         values = values.view('i8')
+    elif is_extension_array_dtype(block.dtype) or is_extension_array(values):
+        extension = ("other", ())
     else:
         extension = ('numpy_type', ())
 
     header = (block.mgr_locs.as_array, values.dtype, values.shape, extension)
-    bytes = pnp.compress(pnp.serialize(values), values.dtype)
+    if extension == ("other", ()):
+        bytes = pickle.dumps(values)
+    else:
+        bytes = pnp.compress(pnp.serialize(values), values.dtype)
     return header, bytes
 
 
 def block_from_header_bytes(header, bytes):
     placement, dtype, shape, (extension_type, extension_values) = header
-    values = pnp.deserialize(pnp.decompress(bytes, dtype), dtype,
-                             copy=True).reshape(shape)
+
+    if extension_type == "other":
+        values = pickle.loads(bytes)
+    else:
+        values = pnp.deserialize(pnp.decompress(bytes, dtype), dtype,
+                                 copy=True).reshape(shape)
     if extension_type == 'categorical_type':
         values = pd.Categorical.from_codes(values,
                                            extension_values[1],
